pub struct TradeHTTP { /* private fields */ }Trait Implementations
Sourceimpl Trade for TradeHTTP
impl Trade for TradeHTTP
Sourcefn new(http_manager: Arc<HttpManager>) -> Self
fn new(http_manager: Arc<HttpManager>) -> Self
Sourcefn place_order<'life0, 'async_trait>(
&'life0 self,
query: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Value, Box<dyn Error + Send + Sync + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn place_order<'life0, 'async_trait>(
&'life0 self,
query: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Value, Box<dyn Error + Send + Sync + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
This method supports to create the order for spot, spot margin, linear perpetual, inverse futures and options. Required args: category (string): Product type Unified account: spot, linear, optionNormal account: linear, inverse. Please note that category is not involved with business logic symbol (string): Symbol name side (string): Buy, Sell orderType (string): Market, Limit qty (string): Order quantity Returns: Request results as JSON data. Additional information: https://bybit-exchange.github.io/docs/v5/order/create-order
Sourcefn amend_order<'life0, 'async_trait>(
&'life0 self,
query: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Value, Box<dyn Error + Send + Sync + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn amend_order<'life0, 'async_trait>(
&'life0 self,
query: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Value, Box<dyn Error + Send + Sync + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Unified account covers: Linear contract / Options Normal account covers: USDT perpetual / Inverse perpetual / Inverse futures Required args: category (string): Product type Unified account: spot, linear, optionNormal account: linear, inverse. Please note that category is not involved with business logic symbol (string): Symbol name Returns: Request results as JSON data. Additional information:
Sourcefn cancel_order<'life0, 'async_trait>(
&'life0 self,
query: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Value, Box<dyn Error + Send + Sync + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn cancel_order<'life0, 'async_trait>(
&'life0 self,
query: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Value, Box<dyn Error + Send + Sync + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Unified account covers: Spot / Linear contract / Options Normal account covers: USDT perpetual / Inverse perpetual / Inverse futures Required args: category (string): Product type Unified account: spot, linear, optionNormal account: linear, inverse. Please note that category is not involved with business logic symbol (string): Symbol name orderId (string): Order ID. Either orderId or orderLinkId is required orderLinkId (string): User customised order ID. Either orderId or orderLinkId is required Returns: Request results as JSON data. Additional information: https://bybit-exchange.github.io/docs/v5/order/cancel-order
Sourcefn get_open_orders<'life0, 'async_trait>(
&'life0 self,
query: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Value, Box<dyn Error + Send + Sync + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_open_orders<'life0, 'async_trait>(
&'life0 self,
query: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Value, Box<dyn Error + Send + Sync + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Query unfilled or partially filled orders in real-time. To query older order records, please use the order history interface. Required args: category (string): Product type Unified account: spot, linear, optionNormal account: linear, inverse. Please note that category is not involved with business logic Returns: Request results as JSON data. Additional information: https://bybit-exchange.github.io/docs/v5/order/open-order
Sourcefn cancel_all_orders<'life0, 'async_trait>(
&'life0 self,
query: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Value, Box<dyn Error + Send + Sync + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn cancel_all_orders<'life0, 'async_trait>(
&'life0 self,
query: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Value, Box<dyn Error + Send + Sync + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Cancel all open orders Required args: category (string): Product type Unified account: spot, linear, option Normal account: linear, inverse. Please note that category is not involved with business logic. If cancel all by baseCoin, it will cancel all linear & inverse orders Returns: Request results as JSON data. Additional information: https://bybit-exchange.github.io/docs/v5/order/cancel-all
Sourcefn get_order_history<'life0, 'async_trait>(
&'life0 self,
query: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Value, Box<dyn Error + Send + Sync + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_order_history<'life0, 'async_trait>(
&'life0 self,
query: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Value, Box<dyn Error + Send + Sync + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Query order history. As order creation/cancellation is asynchronous, the data returned from this endpoint may delay. If you want to get real-time order information, you could query this endpoint or rely on the websocket stream (recommended). Required args: category (string): Product type Unified account: spot, linear, option Normal account: linear, inverse. Please note that category is not involved with business logic Returns: Request results as JSON data. Additional information: https://bybit-exchange.github.io/docs/v5/order/order-list
Sourcefn amend_batch_order<'life0, 'async_trait>(
&'life0 self,
query: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Value, Box<dyn Error + Send + Sync + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn amend_batch_order<'life0, 'async_trait>(
&'life0 self,
query: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Value, Box<dyn Error + Send + Sync + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Covers: Option (Unified Account) Required args: category (string): Product type. option request (array): Object > symbol (string): Symbol name > side (string): Buy, Sell > orderType (string): Market, Limit > qty (string): Order quantity Returns: Request results as JSON data. Additional information: https://bybit-exchange.github.io/docs/v5/order/batch-place
Sourcefn cancel_batch_order<'life0, 'async_trait>(
&'life0 self,
query: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Value, Box<dyn Error + Send + Sync + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn cancel_batch_order<'life0, 'async_trait>(
&'life0 self,
query: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Value, Box<dyn Error + Send + Sync + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
This endpoint allows you to cancel more than one open order in a single request. Required args: category (string): Product type. option request (array): Object > symbol (string): Symbol name Returns: Request results as JSON data. Additional information: https://bybit-exchange.github.io/docs/v5/order/batch-cancel
Sourcefn get_borrow_quota<'life0, 'async_trait>(
&'life0 self,
query: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Value, Box<dyn Error + Send + Sync + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_borrow_quota<'life0, 'async_trait>(
&'life0 self,
query: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Value, Box<dyn Error + Send + Sync + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Query the qty and amount of borrowable coins in spot account. Required args: category (string): Product type. spot symbol (string): Symbol name side (string): Transaction side. Buy,Sell Returns: Request results as JSON data. Additional information: https://bybit-exchange.github.io/docs/v5/order/spot-borrow-quota
Sourcefn set_dcp<'life0, 'async_trait>(
&'life0 self,
query: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Value, Box<dyn Error + Send + Sync + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn set_dcp<'life0, 'async_trait>(
&'life0 self,
query: HashMap<String, String>,
) -> Pin<Box<dyn Future<Output = Result<Value, Box<dyn Error + Send + Sync + 'static>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Covers: Option (Unified Account) Required args: timeWindow (integer): Disconnection timing window time. [10, 300], unit: second Returns: Request results as JSON data. Additional information: https://bybit-exchange.github.io/docs/v5/order/dcp